Learn R Programming

mix (version 1.0-13)

loglik.mix: Loglikelihood for Incomplete Data under the General Location Model

Description

Calculates the observed-data loglikelihood under the general location model at a user-specified parameter value.

Usage

loglik.mix(s, theta)

Value

the value of the loglikelihood function at theta.

Arguments

s

summary list of an incomplete data matrix x created by the function prelim.mix.

theta

parameter list, such as one produced by ecm.mix or da.mix.

References

Schafer, J. L. (1996) Analysis of Incomplete Multivariate Data. Chapman & Hall, Chapter 9.

See Also

prelim.mix, em.mix, ecm.mix.

Examples

Run this code
data(stlouis)
s <- prelim.mix(stlouis,3)       # preliminary manipulations
thetahat <- em.mix(s)      # MLE under unrestricted general location model
loglik.mix(s, thetahat)  # loglikelihood at thetahat

Run the code above in your browser using DataLab