The St. Louis Risk Research Project was an observational study to assess the affects of parental psychological disorders on child development. In the preliminary study, 69 families with 2 children were studied.
data(stlouis)This is a numeric matrix with 69 rows and 7 columns:
[,1] | G | Parental risk group |
[,2] | D1 | Symptoms, child 1 |
[,3] | D2 | Symptoms, child 2 |
[,4] | R1 | Reading score, child 1 |
[,5] | V1 | Verbal score, child 1 |
[,6] | R2 | Reading score, child 2 |
[,7] | V2 | Verbal score, child 2 |
The parental risk group was coded 1, 2 or 3, from low or high, and the
child symptoms 1 = low or 2 = high. Missing values occur on all
variables except G.